package java.security.spec;

import java.util.Objects;
import java.math.BigInteger;

public class RSAMultiPrimePrivateCrtKeySpec extends RSAPrivateKeySpec
{
    private final BigInteger publicExponent;
    private final BigInteger primeP;
    private final BigInteger primeQ;
    private final BigInteger primeExponentP;
    private final BigInteger primeExponentQ;
    private final BigInteger crtCoefficient;
    private final RSAOtherPrimeInfo[] otherPrimeInfo;
    
    public RSAMultiPrimePrivateCrtKeySpec(BigInteger bigInteger, BigInteger bigInteger2, BigInteger bigInteger3, BigInteger bigInteger4, BigInteger bigInteger5, BigInteger bigInteger6, BigInteger bigInteger7, BigInteger bigInteger8, RSAOtherPrimeInfo[] array) {
        this(bigInteger, bigInteger2, bigInteger3, bigInteger4, bigInteger5, bigInteger6, bigInteger7, bigInteger8, array, null);
    }
    
    public RSAMultiPrimePrivateCrtKeySpec(BigInteger obj, BigInteger obj2, BigInteger obj3, BigInteger obj4, BigInteger obj5, BigInteger obj6, BigInteger obj7, BigInteger obj8, RSAOtherPrimeInfo[] array, AlgorithmParameterSpec algorithmParameterSpec) {
        super(obj, obj3, algorithmParameterSpec);
        Objects.requireNonNull(obj, "the modulus parameter must be non-null");
        Objects.requireNonNull(obj3, "the privateExponent parameter must be non-null");
        this.publicExponent = (BigInteger)Objects.requireNonNull(obj2, "the publicExponent parameter must be non-null");
        this.primeP = (BigInteger)Objects.requireNonNull(obj4, "the primeP parameter must be non-null");
        this.primeQ = (BigInteger)Objects.requireNonNull(obj5, "the primeQ parameter must be non-null");
        this.primeExponentP = (BigInteger)Objects.requireNonNull(obj6, "the primeExponentP parameter must be non-null");
        this.primeExponentQ = (BigInteger)Objects.requireNonNull(obj7, "the primeExponentQ parameter must be non-null");
        this.crtCoefficient = (BigInteger)Objects.requireNonNull(obj8, "the crtCoefficient parameter must be non-null");
        if (array == null) {
            this.otherPrimeInfo = null;
        }
        else {
            if (array.length == 0) {
                throw new IllegalArgumentException("the otherPrimeInfo parameter must not be empty");
            }
            this.otherPrimeInfo = (RSAOtherPrimeInfo[])array.clone();
        }
    }
    
    public BigInteger getPublicExponent() {
        return this.publicExponent;
    }
    
    public BigInteger getPrimeP() {
        return this.primeP;
    }
    
    public BigInteger getPrimeQ() {
        return this.primeQ;
    }
    
    public BigInteger getPrimeExponentP() {
        return this.primeExponentP;
    }
    
    public BigInteger getPrimeExponentQ() {
        return this.primeExponentQ;
    }
    
    public BigInteger getCrtCoefficient() {
        return this.crtCoefficient;
    }
    
    public RSAOtherPrimeInfo[] getOtherPrimeInfo() {
        if (this.otherPrimeInfo == null) {
            return null;
        }
        return (RSAOtherPrimeInfo[])this.otherPrimeInfo.clone();
    }
}
